Database fixtures
=================

SQLAlchemy
----------

Charlatan has been heavily used and tested with sqlalchemy. Here's a simple
example:

Tests:

.. literalinclude:: ../charlatan/tests/example/test_sqlalchemy.py

YAML file:

.. literalinclude:: ../charlatan/tests/example/data/sqlalchemy.yaml

Model definition:

.. literalinclude:: ../charlatan/tests/fixtures/models.py
